==> wlp-webProfile7-22.0.0.12.zip: OSGI-INF/welcome/nls/hu/messages.js <==
var messages = {
    WELCOME: "Üdvözli a Liberty",
    WEBSPHERE_LIBERTY_LOGO: "WebSphere Liberty logó",
    OPEN_LIBERTY_LOGO: "Open Liberty logó ",
    WELCOME_SECTION: "Üdvözlő szakasz",
    WELCOME_SECTION_CONTENT: "Üdvözlő szakasz tartalma",
    WEBSPHERE_APPSERVER: "WebSphere Application Server béta",
    HOW_TO_SETUP_ADMIN_CENTER: "Az Admin Center beállítása",
    OPEN_ADMIN_CENTER: "Az Admin Center megnyitása",
    ADDITIONAL_RESOURCES: "További erőforrások",
    EXTERNAL_RESOURCES: "Külső erőforrások",
    OPEN_LIBERT_SUPPORT: "Open Liberty közösség ",
    WEBSPHERE_LIBERTY_DOC: "WebSphere Liberty dokumentáció",
    APPLICABLE_CONTENT: "A WebSphere Liberty számára érvényes összes Open Liberty tartalom:",
    OPEN_LIBERTY_DOC: "Open Liberty dokumentáció",
    OPEN_LIBERTY_GUIDES: "Open Liberty kézikönyvek",
    WEBSPHERE_LIBERTY_FORUM: "WebSphere Liberty fórum ",
    HEADER_UPDATE_AVAILABLE: "Rendelkezésre álló frissítés: ",
    HEADER_DOWNLOAD_LINK: "Kattintson ide {0} letöltéséhez", // Product name
    HEADER_UPDATE_AVAILABLE_DOWNLOAD_LINK: "Frissítés áll rendelkezésre. Kattintson ide {0} letöltéséhez", // Product name
    COPYRIGHT: "Szerzői jogok",
    IBM_LOGO: "IBM logó",
    IBM_LICENSED: "Licenc hatálya alá tartozó anyagok - Az IBM  © Corp. tulajdona. Copyright IBM Corp. 1997, 2019. Minden jog fenntartva. Az IBM, az IBM logó az International Business Machines Corp. védjegye vagy bejegyzett védjegye a világ számos jogrendszerében. Más termék- és szolgáltatásnevek az IBM vagy más vállalatok védjegyei lehetnek. Az IBM védjegyek aktuális listája megtalálható a weben: {0} ", // COPYRIGHT_URL
    COPYRIGHT_URL: "Szerzői jogi és védjegy-információk",
    CONTEXT_ROOT_NOT_FOUND: "A kontextusgyökér nem található",
    UPDATE_BANNER_CLOSE_BUTTON: "Fejléccsík bezárása",
    UPDATE_BANNER_SECTION: "Fejléccsík szakasz frissítése",
    UPDATE_BANNER_SECTION_CONTENT: "Fejléccsík szakasz tartalom frissítése",
    BUILT_ON: "Ráépítve a következővel: ",
    LINKS: "Hivatkozások: "
};

==> wlp-webProfile8-20.0.0.8.zip: OSGI-INF/welcome/nls/hu/messages.js <==
var messages = {
    WELCOME: "Üdvözli a Liberty",
    WEBSPHERE_LIBERTY_LOGO: "WebSphere Liberty logó",
    WELCOME_SECTION: "Üdvözlő szakasz",
    WELCOME_SECTION_CONTENT: "Üdvözlő szakasz tartalma",
    WEBSPHERE_APPSERVER: "WebSphere Application Server béta",
    HOW_TO_SETUP_ADMIN_CENTER: "Az Admin Center beállítása",
    OPEN_ADMIN_CENTER: "Az Admin Center megnyitása",
    ADDITIONAL_RESOURCES: "További erőforrások",
    EXTERNAL_RESOURCES: "Külső erőforrások",
    WASDEV: "WASdev közösség",
    LIBERTY_DOC: "Liberty dokumentáció",
    WASDEV_FORUM: "WASdev fórum",
    HEADER_UPDATE_AVAILABLE: "Rendelkezésre álló frissítés: ",
    HEADER_DOWNLOAD_LINK: "Kattintson ide {0} letöltéséhez", // Product name
    HEADER_UPDATE_AVAILABLE_DOWNLOAD_LINK: "Frissítés áll rendelkezésre. Kattintson ide {0} letöltéséhez", // Product name
    COPYRIGHT: "Szerzői jogok",
    IBM_LOGO: "IBM logó",
    IBM_LICENSED: "Licenc hatálya alá tartozó anyagok - Az IBM  © Corp. tulajdona. Copyright IBM Corp. 1997, 2019. Minden jog fenntartva. Az IBM, az IBM logó az International Business Machines Corp. védjegye vagy bejegyzett védjegye a világ számos jogrendszerében. Más termék- és szolgáltatásnevek az IBM vagy más vállalatok védjegyei lehetnek. Az IBM védjegyek aktuális listája megtalálható a weben: {0} ", // COPYRIGHT_URL
    COPYRIGHT_URL: "Szerzői jogi és védjegy-információk",
    CONTEXT_ROOT_NOT_FOUND: "A kontextusgyökér nem található",
    UPDATE_BANNER_CLOSE_BUTTON: "Fejléccsík bezárása",
    UPDATE_BANNER_SECTION: "Fejléccsík szakasz frissítése",
    UPDATE_BANNER_SECTION_CONTENT: "Fejléccsík szakasz tartalom frissítése",
    BUILT_ON: "Ráépítve a következővel: ",
    LINKS: "Hivatkozások:"
};
